pub struct DefaultStyle(/* private fields */);Expand description
W Default toggle style.
Extends the button::DefaultStyle to have the pressed look when is_checked.
Implementations
Sourceimpl DefaultStyle
impl DefaultStyle
Sourcepub fn is_checked(&self, state: impl IntoVar<bool>)
pub fn is_checked(&self, state: impl IntoVar<bool>)
P If the toggle is checked from any of the three primary properties.
Note to read the tristate directly use IS_CHECKED_VAR directly.
Sourceimpl DefaultStyle
impl DefaultStyle
Sourcepub fn scroll_on_select(&self, enabled: impl IntoVar<bool>)
pub fn scroll_on_select(&self, enabled: impl IntoVar<bool>)
P If the widget scrolls into view when the value selected.
This is enabled by default.
Sourceimpl DefaultStyle
impl DefaultStyle
Sourcepub fn widget_new() -> Self
pub fn widget_new() -> Self
Start building a new instance.
Sourcepub fn widget_type() -> WidgetType
pub fn widget_type() -> WidgetType
Gets the widget type info.
Methods from Deref<Target = DefaultStyle>
Methods from Deref<Target = Style>
Sourcepub fn replace(&self, replace: impl IntoValue<bool>)
pub fn replace(&self, replace: impl IntoValue<bool>)
B Fully replace the contextual style.
This is not enabled by default, if set to true the contextual style properties are removed.
Sourcepub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
pub fn named_style_fn(&self, name: impl IntoValue<NamedStyleVar>)
B Set in the default properties of a named style to define the contextual variable for that style.
During widget instantiation, if this is set by default in a style the contextual style is used as the defaults and only the properties set on the style instance replace them.
This property is part of the named styles pattern, see impl_named_style_fn! for more details.
Note that this property expects a ContextVar<StyleFn> as a value, not a variable directly, it will also only work if
set in the default properties of a style type.